==> haskell-tasty-hunit-0.10.0.2-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hunit
version: 0.10.0.2
id: tasty-hunit-0.10.0.2-4U8Z3WN7pmQARgAmWcNaUv
key: tasty-hunit-0.10.0.2-4U8Z3WN7pmQARgAmWcNaUv
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.
    .
    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.
category: Testing
abi: 40ef80a276b1c410fb3ee5bc4081fd05
exposed: True
exposed-modules:
    Test.Tasty.HUnit
hidden-modules: Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-hunit-0.10.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-hunit-0.10.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-hunit-0.10.0.2
hs-libraries: HStasty-hunit-0.10.0.2-4U8Z3WN7pmQARgAmWcNaUv
depends:
    base-4.12.0.0 call-stack-0.2.0-7WtbHJpXoU7ImWgyG0WuEu
    tasty-1.2.3-HVtsfsVGsB3ReS9DqXVTz
haddock-interfaces: /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html: /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-hunit-0.10.0.2-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-hunit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-hunit
version: 0.10.0.2
id: tasty-hunit-0.10.0.2-9F27rD5uewhBp6reItFGzQ
key: tasty-hunit-0.10.0.2-9F27rD5uewhBp6reItFGzQ
license: MIT
maintainer: Roman Cheplyaka <roma@ro-che.info>
author: Roman Cheplyaka <roma@ro-che.info>
homepage: https://github.com/feuerbach/tasty
synopsis: HUnit support for the Tasty test framework.
description:
    HUnit support for the Tasty test framework.
    .
    Note that this package does not depend on HUnit but
    implements the relevant subset of its API. The name is a
    legacy of the early versions of tasty-hunit and of
    test-framework-hunit, which did depend on HUnit.
category: Testing
abi: 3a74c9c758569b6485854cba1f5173e4
exposed: True
exposed-modules:
    Test.Tasty.HUnit
hidden-modules: Test.Tasty.HUnit.Orig Test.Tasty.HUnit.Steps
import-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-hunit-0.10.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/tasty-hunit-0.10.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tasty-hunit-0.10.0.2
hs-libraries: HStasty-hunit-0.10.0.2-9F27rD5uewhBp6reItFGzQ
depends:
    base-4.12.0.0 call-stack-0.2.0-9ngidej6WIpECW9h0xxcD3
    tasty-1.2.3-HVtsfsVGsB3ReS9DqXVTz
haddock-interfaces: /usr/share/doc/haskell-tasty-hunit/html/tasty-hunit.haddock
haddock-html: /usr/share/doc/haskell-tasty-hunit/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
